SingleSelection<T> class
A class representing a single selection widget.
This widget allows users to select a single item from a list.
It extends the _Selection class and overrides the _isSelected and _update methods
to handle single selection.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SingleSelection
Constructors
-
SingleSelection({Key? key, required List<
T> data, T? init, required dynamic onChanged(T item), double spacing = 8.0, double? runSpacing, SelectionLayout layout = SelectionLayout.wrap, Widget builder(T item, bool isSelected)?}) -
const
Properties
- builder → Widget Function(T item, bool isSelected)?
-
finalinherited
-
data
→ List<
T> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- init → dynamic
-
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- layout → SelectionLayout
-
finalinherited
- onChanged → Function?
-
finalinherited
- runSpacing → double?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
finalinherited
Methods
-
build(
T item, bool isSelected) → Widget -
Builds the widget for a given item.
If a custom builder is provided, it uses that; otherwise, it defaults to a
Textwidget.inherited -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< _Selection< T> > -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited